@@ -178,9 +178,9 @@ const SearchProvider = new Lang.Class({
             let name = location.get_city_name();
             let conditions = Util.getWeatherConditions(info);
 
-            // TRANSLATORS: this is the description shown in the overview search
-            // It's the current weather conditions followed by the temperature,
-            // like "Clear sky, 14 °C"
+            /* TRANSLATORS: this is the description shown in the overview search
+               It's the current weather conditions followed by the temperature,
+               like "Clear sky, 14 °C" */
             let summary = _("%s, %s").format(conditions, info.get_temp());
             ret.push({ name: new GLib.Variant('s', name),
                        id: new GLib.Variant('s', identifiers[i]),
